<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>Estén</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>Només a %1</translation>
    </message>
</context>
</TS>